History
=======

0.8 - 2013-07-14
----------------

- Nicer progress bar
- Added the --json-output option
- Integrated Tox
- Make sure the DNS resolution works with gevent 0.x and 1.x
- Improved tests
- Removed the globals


0.7 - 2013-05-21
----------------

- fixed the TypeError on empty stats - #19
- catch the dns error and display it nicely
- added SSL support - #17
- added clean error display - #16

No notes on earlier releases.
